
# parsetab.py
# This file is automatically generated. Do not edit.
# pylint: disable=W,C,R
_tabversion = '3.10'

_lr_method = 'LALR'

_lr_signature = 'GRAMMARRULE LPAREN RPARENRelevantData : DataLinesDataLines : DataLine\n                 | DataLines DataLineDataLine : LPAREN GRAMMARRULE RPAREN'
    
_lr_action_items = {'GRAMMARRULE':([3,],[5,]),'LPAREN':([0,1,4,6,7,],[3,-2,3,-3,-4,]),'RPAREN':([5,],[7,]),'$end':([1,2,4,6,7,],[-2,0,-1,-3,-4,]),}

_lr_action = {}
for _k, _v in _lr_action_items.items():
   for _x,_y in zip(_v[0],_v[1]):
      if not _x in _lr_action:  _lr_action[_x] = {}
      _lr_action[_x][_k] = _y
del _lr_action_items

_lr_goto_items = {'DataLine':([0,4,],[1,6,]),'DataLines':([0,],[4,]),'RelevantData':([0,],[2,]),}

_lr_goto = {}
for _k, _v in _lr_goto_items.items():
   for _x, _y in zip(_v[0], _v[1]):
       if not _x in _lr_goto: _lr_goto[_x] = {}
       _lr_goto[_x][_k] = _y
del _lr_goto_items
_lr_productions = [
  ("S' -> RelevantData","S'",1,None,None,None),
  ('RelevantData -> DataLines','RelevantData',1,'p_relevantdata','parsetabtolatex_yacc.py',15),
  ('DataLines -> DataLine','DataLines',1,'p_datalines','parsetabtolatex_yacc.py',19),
  ('DataLines -> DataLines DataLine','DataLines',2,'p_datalines','parsetabtolatex_yacc.py',20),
  ('DataLine -> LPAREN GRAMMARRULE RPAREN','DataLine',3,'p_dataline','parsetabtolatex_yacc.py',27),
]
